@@ -6,8 +6,10 @@ from pathlib import Path
 import pytest
 import vdf
 
-from protontricks.steam import (SteamApp, find_appid_proton_prefix,
-                                find_steam_compat_tool_app, find_steam_path,
+from protontricks.steam import (SteamApp, _get_steamapps_subdirs,
+                                find_appid_proton_prefix,
+                                find_steam_compat_tool_app,
+                                find_steam_installations, find_steam_path,
                                 get_custom_compat_tool_installations,
                                 get_custom_windows_shortcuts, get_steam_apps,
                                 get_steam_lib_paths)
@@ -579,13 +581,18 @@ class TestFindSteamPath:
         steam_flatpak_dir.parent.mkdir(parents=True)
         shutil.copytree(steam_dir, steam_flatpak_dir)
 
-        # Since Flatpak is enabled, both paths should point to Flatpak
-        steam_path, steam_root = find_steam_path()
+        steam_installations = find_steam_installations()
+        steam_path, steam_root = next(
+            (steam_path, steam_root) for (steam_path, steam_root) in
+            steam_installations
+            if str(steam_path) == str(steam_flatpak_dir)
+        )
 
+        # Since Steam Flatpak installation was found, both of its paths
+        # should point to the same installation directory
         assert str(steam_path) == str(steam_flatpak_dir)
         assert str(steam_root) == str(steam_flatpak_dir)
 
-    @pytest.mark.usefixtures("flatpak_sandbox")
     def test_find_steam_path_multiple_install_warning(
             self, steam_dir, steam_root, home_dir, caplog):
         """
@@ -605,8 +612,8 @@ class TestFindSteamPath:
         assert "STEAM_DIR=<path>" in caplog.records[3].message
         assert "The following Steam directories were found" \
             in caplog.records[4].message
-        assert str(steam_flatpak_dir) in caplog.records[5].message
-        assert str(steam_dir) in caplog.records[6].message
+        assert str(steam_dir) in caplog.records[5].message
+        assert str(steam_flatpak_dir) in caplog.records[6].message
 
 
 class TestGetSteamApps:
@@ -881,9 +888,9 @@ class TestGetSteamApps:
             record for record in caplog.records
             if record.levelname == "WARNING"
         ]
-        assert len(warnings) == 1
+        assert len(warnings) == 2
 
-        warning = warnings[0]
+        warning = warnings[-1]
         assert f"{library_dir_b} not found." in warning.message
 
 
@@ -991,3 +998,22 @@ class TestGetWindowsShortcuts:
             "Shortcut fakegame.exe (4149337689) does not have a prefix"
             in record.message
         )
+
+
+def test_get_steamapps_subdirs(steam_dir, steam_library_factory):
+    """
+    Retrieve Steam library directory containing multiple 'steamapps'
+    directories. Ensure the one with the exact 'steamapps' case is picked
+    first.
+    """
+    library = steam_library_factory("TestLibrary")
+
+    (library / "SteamApps").mkdir()
+    (library / "STEAMAPPS").mkdir()
+    (library / "steamapps").mkdir()
+    (library / "SteaMAppS").mkdir()
+
+    steamapps_dirs = _get_steamapps_subdirs(library)
+
+    assert len(steamapps_dirs) == 4
+    assert steamapps_dirs[0].name == "steamapps"
